/* vim: ts=4 sw=4 noet
 */
body {
	background-color: #3679AD;
	color: #000000;
	margin-left: 0;
	margin-right: 0;
	margin-top: 5;
	padding: 0;
	background-image: url(background.png);
	background-repeat: no-repeat;
	background-position: top-center;
}

div.greyline {
	background: #505050;
	height: 15px;
}
div.shadow1 {
	background-image: url(shadow1.png);
	background-repeat: x-repeat;
	height: 9px;
}
div.trans {
	background: #d0dfec;
	background-image: url(bgtable.png);
	background-repeat: no-repeat;
	margin: 15px; padding: 12px;
}
div.end {
	background-image: url(lines2.png);
	background-repeat: x-repeat;
	text-align: right;
}

a:link {
	background-color: transparent;
	color: #191970;
	text-decoration:none;
}
a:visited {
	background-color: transparent;
	color: #551a8a;
	text-decoration:none;
}
a:active {
	background-color: transparent;
	color: #fe0000;
	text-decoration:none;
}
a:hover {
	background-color: transparent;
	color: #1919aa;
	text-decoration:underline;
}
