( cd opt/kde/share/doc/HTML/en/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpackage ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksysv ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kuser ; ln -sf /opt/kde/share/doc/HTML/en/common common )
