<!DOCTYPE kpartgui >
<kpartgui name="kpackage" version="3">
 <MenuBar>
  <Menu name="file" >
  <text>&amp;File</text>
  <Action name="pack_find" />
  <Action name="pack_findf" />
  <Separator/>
 <Action name="kpack_reload" />
</Menu>

<Menu name="packages" >
 <text>&amp;Packages</text>
 <Action name="pack_prev" />
 <Action name="pack_next" />
 <Separator/>
 <Action name="kpack_expand" />
 <Action name="kpack_collapse" />
 <Separator/>
 <Action name="kpack_clear" />
 <Action name="kpack_markall" />
 <Separator/>
 <Action name="install_single" />
 <Action name="install_marked" />
 <Action name="uninstall_single" />
 <Action name="uninstall_marked" />
</Menu>

<Menu name="cache" >
 <text>&amp;Cache</text> 
 <Action name="clear_dcache" />
 <Action name="clear_pcache" />
</Menu>

<Menu name="special" >
 <text>Spe&amp;cial</text> 
 <Menu name="debapt" >
  <text>&amp;APT: Debian</text> 
  <Action name="debapt_update" />
  <Action name="debapt_upgrade" />
  <Action name="debapt_fixup" />
 </Menu>
</Menu>

<Menu name="settings" >
 <text>&amp;Settings</text>
 <Action name="kpack_options" append="configure_merge"/>
</Menu>
</MenuBar>
 <ToolBar  position="Left" name="mainToolBar" >
  <Action name="pack_prev" />
  <Action name="pack_next" />
  <Action name="kpack_expand" />
  <Action name="kpack_collapse" />
  <Action name="pack_find" />
  <Action name="pack_findf" />
  <Action name="kpack_reload" />
  <Action name="file_quit" />
 </ToolBar>
</kpartgui>
